@@ -8,7 +8,7 @@ from core_composer_app.components.type_version_manager.models import (
 )
 from core_main_app.access_control.api import is_superuser
 from core_main_app.access_control.decorators import access_control
-from core_main_app.components.template.access_control import can_read
+from core_main_app.components.template.access_control import can_read_id
 from core_main_app.components.template.access_control import can_read_global
 from core_main_app.components.template_version_manager.access_control import (
     can_write,
@@ -19,7 +19,7 @@ from core_main_app.components.version_manager.utils import (
 )
 
 
-@access_control(can_read)
+@access_control(can_read_id)
 def get_by_id(version_manager_id, request):
     """Get a type version manager by its id.
 
@@ -126,18 +126,16 @@ def get_no_buckets_types(request):
     Returns:
 
     """
-    # build list of types
-    bucket_types = []
+    # Retrieve IDs of types in buckets.
+    bucket_type_id_list = []
     for bucket in bucket_api.get_all():
-        bucket_types += bucket.types.all()
+        bucket_type_id_list += [
+            bucket_type.pk for bucket_type in bucket.types.all()
+        ]
 
-    all_types = get_global_version_managers(request=request)
-    no_bucket_types = [
-        type_version_manager
-        for type_version_manager in all_types
-        if type_version_manager not in bucket_types
-    ]
-    return no_bucket_types
+    return get_global_version_managers(request=request).exclude(
+        pk__in=bucket_type_id_list
+    )
 
 
 @access_control(is_superuser)
