@@ -5,8 +5,12 @@ from os.path import join
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
 from django.contrib.staticfiles import finders
-from django.urls import reverse_lazy
 
+from core_composer_app.components.bucket import api as bucket_api
+from core_composer_app.components.type_version_manager import (
+    api as type_version_manager_api,
+)
+from core_composer_app.permissions import rights
 from core_main_app.components.template import api as template_api
 from core_main_app.components.template_version_manager import (
     api as template_version_manager_api,
@@ -20,11 +24,7 @@ from xml_utils.commons.constants import LXML_SCHEMA_NAMESPACE
 from xml_utils.xsd_tree.operations.annotation import remove_annotations
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 from xml_utils.xsd_types.xsd_types import get_xsd_types
-from core_composer_app.components.bucket import api as bucket_api
-from core_composer_app.components.type_version_manager import (
-    api as type_version_manager_api,
-)
-from core_composer_app.permissions import rights
+
 
 # TODO: see if sessions are problematic
 
@@ -32,7 +32,6 @@ from core_composer_app.permissions import rights
 @decorators.permission_required(
     content_type=rights.COMPOSER_CONTENT_TYPE,
     permission=rights.COMPOSER_ACCESS,
-    login_url=reverse_lazy("core_main_app_login"),
 )
 def index(request):
     """Page that allows to select a template to start composing.
@@ -88,7 +87,6 @@ def index(request):
 @decorators.permission_required(
     content_type=rights.COMPOSER_CONTENT_TYPE,
     permission=rights.COMPOSER_ACCESS,
-    login_url=reverse_lazy("core_main_app_login"),
 )
 def build_template(request, template_id):
     """View that allows to build the Template.
@@ -140,24 +138,32 @@ def build_template(request, template_id):
     # transform XML to HTML
     xsd_to_html_string = xsl_transform(xsd_string, xslt_string)
 
-    # 1) Get user defined types
+    # 1) Get user defined types.
     user_types = type_version_manager_api.get_version_managers_by_user(
         request=request
-    )
-    # 2) Get buckets
-    buckets = bucket_api.get_all()
+    ).filter(is_disabled=False)
 
-    # 3) no_buckets_types: list of types that are not assigned to a specific bucket
+    # 2) Get buckets.
+    buckets = [
+        {
+            "label": bucket.label,
+            "color": bucket.color,
+            "types": bucket.types.filter(is_disabled=False),
+        }
+        for bucket in bucket_api.get_all()
+    ]
+
+    # 3) no_buckets_types: list of types that are not assigned to a specific
+    #   bucket.
     no_buckets_types = type_version_manager_api.get_no_buckets_types(
         request=request
-    )
+    ).filter(is_disabled=False)
 
     # 4) Build list of built-in types
-    built_in_types = []
-    for built_in_type in get_xsd_types():
-        built_in_types.append(
-            {"current": "built_in_type", "title": built_in_type}
-        )
+    built_in_types = [
+        {"current": "built_in_type", "title": built_in_type}
+        for built_in_type in get_xsd_types()
+    ]
 
     assets = {
         "js": [
@@ -201,7 +207,6 @@ def build_template(request, template_id):
         "core_composer_app/user/builder/modals/change_type.html",
         "core_composer_app/user/builder/modals/save_template.html",
         "core_composer_app/user/builder/modals/save_type.html",
-        "core_composer_app/user/builder/modals/save_success.html",
         "core_composer_app/user/builder/modals/occurrences.html",
         "core_composer_app/user/builder/modals/errors.html",
     ]
@@ -221,7 +226,6 @@ def build_template(request, template_id):
 @decorators.permission_required(
     content_type=rights.COMPOSER_CONTENT_TYPE,
     permission=rights.COMPOSER_ACCESS,
-    login_url=reverse_lazy("core_main_app_login"),
 )
 def download_xsd(request):
     """Make the current XSD available for download.
